==> org-lsst-ccs-subsystem-fcs-buses-7.0.4-20240719.082618-8-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselBrakes.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.BrakeState;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByCarouselBrakes implements Serializable{

    @DataAttributes(description = "State of carousel brake 1 {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState1;

    @DataAttributes(description = "State of carousel brake 2 {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState2;

    @DataAttributes(description = "State of carousel brake 2 {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState3;

    @DataAttributes(description = "Temperature of carousel motor", units = "Celsius")
    private double temperature1;

    @DataAttributes(description = "Temperature of carousel brake bay I", units = "Celsius")
    private double temperature2;

    @DataAttributes(description = "Temperature of carousel brake bay N", units = "Celsius")
    private double temperature3;

    @DataAttributes(description = "Temperature of carousel brake bay X", units = "Celsius")
    private double temperature4;

    @DataAttributes(description = "Carousel brake sensor bay I value", units = "unitless")
    private long sensor1;

    @DataAttributes(description = "Carousel brake sensor bay N value", units = "unitless")
    private long sensor2;

    @DataAttributes(description = "Carousel brake sensor bay X value", units = "unitless")
    private long sensor3;


    public BrakeState getBrakeState1() {
        return brakeState1;
    }

    public void setBrakeState1(BrakeState brakeState1) {
        this.brakeState1 = brakeState1;
    }

    public BrakeState getBrakeState2() {
        return brakeState2;
    }

    public void setBrakeState2(BrakeState brakeState2) {
        this.brakeState2 = brakeState2;
    }

    public BrakeState getBrakeState3() {
        return brakeState3;
    }

    public void setBrakeState3(BrakeState brakeState3) {
        this.brakeState3 = brakeState3;
    }


    public long getSensor1() {
        return sensor1;
    }

    public void setSensor1(long sensor1) {
        this.sensor1 = sensor1;
    }

    public long getSensor2() {
        return sensor2;
    }

    public void setSensor2(long sensor2) {
        this.sensor2 = sensor2;
    }

    public long getSensor3() {
        return sensor3;
    }

    public void setSensor3(long sensor3) {
        this.sensor3 = sensor3;
    }


    public double getTemperature1() {
        return temperature1;
    }

    public void setTemperature1(double temperature1) {
        this.temperature1 = temperature1;
    }

    public double getTemperature2() {
        return temperature2;
    }

    public void setTemperature2(double temperature2) {
        this.temperature2 = temperature2;
    }

    public double getTemperature3() {
        return temperature3;
    }

    public void setTemperature3(double temperature3) {
        this.temperature3 = temperature3;
    }

    public double getTemperature4() {
        return temperature4;
    }

    public void setTemperature4(double temperature4) {
        this.temperature4 = temperature4;
    }

}

==> org-lsst-ccs-subsystem-fcs-buses-9.0.1-sources.jar: org/lsst/ccs/subsystems/fcs/StatusDataPublishedByCarouselBrakes.java <==
package org.lsst.ccs.subsystems.fcs;

import java.io.Serializable;
import org.lsst.ccs.bus.annotations.DataAttributes;
import org.lsst.ccs.subsystems.fcs.FcsEnumerations.BrakeState;

/**
 *
 * @author virieux
 */
public class StatusDataPublishedByCarouselBrakes implements Serializable{

    @DataAttributes(description = "State of carousel brake bay I {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState1;

    @DataAttributes(description = "State of carousel brake bay N {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState2;

    @DataAttributes(description = "State of carousel brake bay X {CLOSED; NOBRAKE; NO_SENSOR}", units = "unitless")
    private BrakeState brakeState3;

    @DataAttributes(description = "Temperature of carousel motor on bay D", units = "Celsius")
    private double temperature1;

    @DataAttributes(description = "Temperature of carousel brake bay I", units = "Celsius")
    private double temperature2;

    @DataAttributes(description = "Temperature of carousel brake bay N", units = "Celsius")
    private double temperature3;

    @DataAttributes(description = "Temperature of carousel brake bay X", units = "Celsius")
    private double temperature4;

    @DataAttributes(description = "Carousel brake sensor bay I value", units = "unitless")
    private long sensor1;

    @DataAttributes(description = "Carousel brake sensor bay N value", units = "unitless")
    private long sensor2;

    @DataAttributes(description = "Carousel brake sensor bay X value", units = "unitless")
    private long sensor3;


    public BrakeState getBrakeState1() {
        return brakeState1;
    }

    public void setBrakeState1(BrakeState brakeState1) {
        this.brakeState1 = brakeState1;
    }

    public BrakeState getBrakeState2() {
        return brakeState2;
    }

    public void setBrakeState2(BrakeState brakeState2) {
        this.brakeState2 = brakeState2;
    }

    public BrakeState getBrakeState3() {
        return brakeState3;
    }

    public void setBrakeState3(BrakeState brakeState3) {
        this.brakeState3 = brakeState3;
    }


    public long getSensor1() {
        return sensor1;
    }

    public void setSensor1(long sensor1) {
        this.sensor1 = sensor1;
    }

    public long getSensor2() {
        return sensor2;
    }

    public void setSensor2(long sensor2) {
        this.sensor2 = sensor2;
    }

    public long getSensor3() {
        return sensor3;
    }

    public void setSensor3(long sensor3) {
        this.sensor3 = sensor3;
    }


    public double getTemperature1() {
        return temperature1;
    }

    public void setTemperature1(double temperature1) {
        this.temperature1 = temperature1;
    }

    public double getTemperature2() {
        return temperature2;
    }

    public void setTemperature2(double temperature2) {
        this.temperature2 = temperature2;
    }

    public double getTemperature3() {
        return temperature3;
    }

    public void setTemperature3(double temperature3) {
        this.temperature3 = temperature3;
    }

    public double getTemperature4() {
        return temperature4;
    }

    public void setTemperature4(double temperature4) {
        this.temperature4 = temperature4;
    }

}
